@@ -43,11 +43,12 @@ typedef struct _GnomePrintPreview      GnomePrintPreview;
 typedef struct _GnomePrintPreviewClass GnomePrintPreviewClass;
 
 #include <libgnomecanvas/libgnomecanvas.h>
-#include <libgnomeprint/gnome-print-paper.h>
 #include <libgnomeprint/gnome-print.h>
 
 GType gnome_print_preview_get_type  (void);
 
+void gnome_print_preview_reset (GnomePrintPreview *preview);
+
 /*
  * Don't use those functions. Use g_object_new instead and supply a
  * GnomeCanvasGroup as parameter.
@@ -59,4 +60,3 @@ GnomePrintContext * gnome_print_preview_new_full (GnomePrintConfig *config, Gnom
 G_END_DECLS
 
 #endif /* __GNOME_PRINT_PREVIEW_H__ */
-
